==> shntool-1.01.tar.gz: shntool-1.01/include/shntool.h <==
/*  shntool.h - global definitions
 *  Copyright (C) 2000-2001  Jason Jordan (shnutils@freeshell.org)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __SHNTOOL_H__
#define __SHNTOOL_H__

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "format.h"
#include "mode.h"

#define RELEASE   "version " VERSION
#define COPYRIGHT "Copyright 2001"
#define AUTHOR    "Jason Jordan (shnutils@freeshell.org)"
#define URL       ".shn utilities page:  http://shnutils.freeshell.org/"

#define PROGNAME_SIZE 256
#define BUF_SIZE      2048
#define FILENAME_SIZE 2048
#define XFER_SIZE     262144

#define MAX_MODULE_NAME_LENGTH "5"

#define min(x,y) ((x)<(y)?(x):(y))
#define max(x,y) ((x)>(y)?(x):(y))

extern mode_module *modes[];
extern format_module *formats[];

extern char *progname;
extern char *progmode;
extern char fullprogname[];
extern char *author;
extern char *version;
extern char *copyright;
extern char *url;

extern int aliased;

/* generic error function - like printf, but prints to stderr with a prefix of "shntool [current_mode_name]:"
 * If you want to suppress the "Error: " prefix, then make the first character in the string you pass to it
 * a '\0', e.g. error("\0Example that suppresses the Error: prefix");
 */
void error(char *, ...);

#endif

==> shntool-1.2.3.tar.gz: shntool-1.2.3/include/shntool.h <==
/*  shntool.h - global definitions
 *  Copyright (C) 2000-2003  Jason Jordan <shnutils@freeshell.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * $Id: shntool.h,v 1.16 2003/02/12 02:16:03 jason Exp $
 */

#ifndef __SHNTOOL_H__
#define __SHNTOOL_H__

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include "format.h"
#include "mode.h"

#define RELEASE   VERSION
#define COPYRIGHT "Copyright 2000-2003"
#define AUTHOR    "Jason Jordan <shnutils@freeshell.org>"
#define URLS      "  http://www.etree.org/shnutils/\n  http://shnutils.freeshell.org/"

#define SHNTOOL_DEBUG_ENV "SHNTOOL_DEBUG"

#define PROGNAME_SIZE 256
#define BUF_SIZE      2048
#define FILENAME_SIZE 2048
#define XFER_SIZE     262144

#define MAX_MODULE_NAME_LENGTH "5"

#define min(x,y) ((x)<(y)?(x):(y))
#define max(x,y) ((x)>(y)?(x):(y))

#ifdef HAVE_VSNPRINTF
#define my_vsnprintf(a,b,c,d) vsnprintf(a,b,c,d)
#else
#define my_vsnprintf(a,b,c,d) vsprintf(a,c,d)
#endif

extern mode_module *modes[];
extern format_module *formats[];

extern char *progname;
extern char *progmode;
extern char fullprogname[];
extern char *author;
extern char *version;
extern char *copyright;
extern char *urls;

extern int aliased;
extern int shntool_debug;

void warning(char *, ...);
void error(char *, ...);
void help(char *, ...);

#endif
